# -*- coding: utf-8 -*-
"""Reusable Django application that adds a DurationField implementation

The django-durationfield package is a implementation for `#2443 <http://code.djangoproject.com/ticket/2443>`_,
"Add IntervalField to database models." Since the existing patch was not
committed before the 1.2 feature deadline, this package attempts to make the
patch into a reusable application that provides a ``DurationField``.

"""
__version__ = '0.3.4'
